@@ -33,18 +33,17 @@
 #include <dix-config.h>
 #endif
 
-#include <X11/X.h>	/* for inputstr.h    */
-#include <X11/Xproto.h>	/* Request macro     */
-#include "inputstr.h"	/* DeviceIntPtr      */
-#include "windowstr.h"	/* window structure  */
-#include "scrnintstr.h"	/* screen structure  */
+#include <X11/X.h>              /* for inputstr.h    */
+#include <X11/Xproto.h>         /* Request macro     */
+#include "inputstr.h"           /* DeviceIntPtr      */
+#include "windowstr.h"          /* window structure  */
+#include "scrnintstr.h"         /* screen structure  */
 #include <X11/extensions/XI.h>
 #include <X11/extensions/XI2proto.h>
 #include "extnsionst.h"
 #include "exevents.h"
 #include "exglobals.h"
-#include "mipointer.h" /* for miPointerUpdateSprite */
-
+#include "mipointer.h"          /* for miPointerUpdateSprite */
 
 #include "xiwarppointer.h"
 /***********************************************************************
@@ -56,19 +55,17 @@
 int
 SProcXIWarpPointer(ClientPtr client)
 {
-    char n;
-
     REQUEST(xXIWarpPointerReq);
-    swaps(&stuff->length, n);
-    swapl(&stuff->src_win, n);
-    swapl(&stuff->dst_win, n);
-    swapl(&stuff->src_x, n);
-    swapl(&stuff->src_y, n);
-    swaps(&stuff->src_width, n);
-    swaps(&stuff->src_height, n);
-    swapl(&stuff->dst_x, n);
-    swapl(&stuff->dst_y, n);
-    swaps(&stuff->deviceid, n);
+    swaps(&stuff->length);
+    swapl(&stuff->src_win);
+    swapl(&stuff->dst_win);
+    swapl(&stuff->src_x);
+    swapl(&stuff->src_y);
+    swaps(&stuff->src_width);
+    swaps(&stuff->src_height);
+    swapl(&stuff->dst_x);
+    swapl(&stuff->dst_y);
+    swaps(&stuff->deviceid);
     return (ProcXIWarpPointer(client));
 }
 
@@ -91,24 +88,20 @@ ProcXIWarpPointer(ClientPtr client)
 
     rc = dixLookupDevice(&pDev, stuff->deviceid, client, DixWriteAccess);
 
-    if (rc != Success)
-    {
+    if (rc != Success) {
         client->errorValue = stuff->deviceid;
         return rc;
     }
 
-    if ((!IsMaster(pDev) && pDev->u.master) ||
-        (IsMaster(pDev) && !IsPointerDevice(pDev)))
-    {
+    if ((!IsMaster(pDev) && !IsFloating(pDev)) ||
+        (IsMaster(pDev) && !IsPointerDevice(pDev))) {
         client->errorValue = stuff->deviceid;
         return BadDevice;
     }
 
-    if (stuff->dst_win != None)
-    {
+    if (stuff->dst_win != None) {
         rc = dixLookupWindow(&dest, stuff->dst_win, client, DixGetAttrAccess);
-        if (rc != Success)
-        {
+        if (rc != Success) {
             client->errorValue = stuff->dst_win;
             return rc;
         }
@@ -118,19 +111,17 @@ ProcXIWarpPointer(ClientPtr client)
     x = pSprite->hotPhys.x;
     y = pSprite->hotPhys.y;
 
-    src_x = stuff->src_x / (double)(1 << 16);
-    src_y = stuff->src_y / (double)(1 << 16);
-    dst_x = stuff->dst_x / (double)(1 << 16);
-    dst_y = stuff->dst_y / (double)(1 << 16);
+    src_x = stuff->src_x / (double) (1 << 16);
+    src_y = stuff->src_y / (double) (1 << 16);
+    dst_x = stuff->dst_x / (double) (1 << 16);
+    dst_y = stuff->dst_y / (double) (1 << 16);
 
-    if (stuff->src_win != None)
-    {
+    if (stuff->src_win != None) {
         int winX, winY;
         WindowPtr src;
 
         rc = dixLookupWindow(&src, stuff->src_win, client, DixGetAttrAccess);
-        if (rc != Success)
-        {
+        if (rc != Success) {
             client->errorValue = stuff->src_win;
             return rc;
         }
@@ -138,22 +129,22 @@ ProcXIWarpPointer(ClientPtr client)
         winX = src->drawable.x;
         winY = src->drawable.y;
         if (src->drawable.pScreen != pSprite->hotPhys.pScreen ||
-                x < winX + src_x ||
-                y < winY + src_y ||
-                (stuff->src_width != 0 &&
-                 winX + src_x + (int)stuff->src_width < 0) ||
-                (stuff->src_height != 0 &&
-                 winY + src_y + (int)stuff->src_height < y) ||
-                !PointInWindowIsVisible(src, x, y))
+            x < winX + src_x ||
+            y < winY + src_y ||
+            (stuff->src_width != 0 &&
+             winX + src_x + (int) stuff->src_width < 0) ||
+            (stuff->src_height != 0 &&
+             winY + src_y + (int) stuff->src_height < y) ||
+            !PointInWindowIsVisible(src, x, y))
             return Success;
     }
 
-    if (dest)
-    {
+    if (dest) {
         x = dest->drawable.x;
         y = dest->drawable.y;
         newScreen = dest->drawable.pScreen;
-    } else
+    }
+    else
         newScreen = pSprite->hotPhys.pScreen;
 
     x += dst_x;
@@ -169,8 +160,7 @@ ProcXIWarpPointer(ClientPtr client)
     else if (y > newScreen->height)
         y = newScreen->height - 1;
 
-    if (newScreen == pSprite->hotPhys.pScreen)
-    {
+    if (newScreen == pSprite->hotPhys.pScreen) {
         if (x < pSprite->physLimits.x1)
             x = pSprite->physLimits.x1;
         else if (x >= pSprite->physLimits.x2)
@@ -183,21 +173,18 @@ ProcXIWarpPointer(ClientPtr client)
 
         if (pSprite->hotShape)
             ConfineToShape(pDev, pSprite->hotShape, &x, &y);
-        (*newScreen->SetCursorPosition)(pDev, newScreen, x, y, TRUE);
-    } else if (!PointerConfinedToScreen(pDev))
-    {
+        (*newScreen->SetCursorPosition) (pDev, newScreen, x, y, TRUE);
+    }
+    else if (!PointerConfinedToScreen(pDev)) {
         NewCurrentScreen(pDev, newScreen, x, y);
     }
 
     /* if we don't update the device, we get a jump next time it moves */
     pDev->last.valuators[0] = x;
     pDev->last.valuators[1] = y;
-    pDev->last.remainder[0] = 0;
-    pDev->last.remainder[1] = 0;
     miPointerUpdateSprite(pDev);
 
     /* FIXME: XWarpPointer is supposed to generate an event. It doesn't do it
        here though. */
     return Success;
 }
-
